==> jtharness_5.0.orig.tar.xz: jtharness-5.0/src/com/sun/javatest/lib/ReportScript.java <==
/*
 * $Id$
 *
 * Copyright (c) 1996, 2009, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javatest.lib;

import com.sun.javatest.Script;
import com.sun.javatest.Status;
import com.sun.javatest.TestDescription;
import com.sun.javatest.TestEnvironment;
import com.sun.javatest.TestResult;

/**
 * A special script which reads the result file which is presumed to exist in
 * the work directory as the result of a prior run.  This will allow the
 * creation of a TestResult object from a old test run.
 */
public class ReportScript extends Script
{
    public final void run() {
        TestResult tr = getTestResult();
        try {
            tr.reloadFromWorkDir(workDir);
        }
        catch (TestResult.Fault ignore) {
        }
    }

    /** This method should not be called; for this class, its identity
     * is significant, not its implementation.
     *
     * @throws Error if called
     */
    public Status run(String[] args, TestDescription td, TestEnvironment env) {
        throw new Error("should not be called");
    }
}

==> jtharness_6.0-b24.orig.tar.xz: jtharness-6.0-b24/src/com/sun/javatest/lib/ReportScript.java <==
/*
 * $Id$
 *
 * Copyright (c) 1996, 2009, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javatest.lib;

import com.sun.javatest.Script;
import com.sun.javatest.Status;
import com.sun.javatest.TestDescription;
import com.sun.javatest.TestEnvironment;
import com.sun.javatest.TestResult;

/**
 * A special script which reads the result file which is presumed to exist in
 * the work directory as the result of a prior run.  This will allow the
 * creation of a TestResult object from a old test run.
 */
public class ReportScript extends Script {
    @Override
    public final void run() {
        TestResult tr = getTestResult();
        try {
            tr.reloadFromWorkDir(workDir);
        } catch (TestResult.Fault ignore) {
        }
    }

    /**
     * This method should not be called; for this class, its identity
     * is significant, not its implementation.
     *
     * @throws Error if called
     */
    @Override
    public Status run(String[] args, TestDescription td, TestEnvironment env) {
        throw new Error("should not be called");
    }
}
